@@ -22,6 +22,7 @@ from esi.decorators import token_required
 from esi.models import Token
 
 from imicusfat import __title__
+from imicusfat.app_settings import IMICUSFAT_DEFAULT_FATLINK_EXPIRY_TIME
 from imicusfat.forms import FatLinkForm, ManualFatForm, ClickFatForm, FatLinkEditForm
 from imicusfat.models import (
     IFat,
@@ -761,8 +762,17 @@ def links_data(request, year: int = None) -> JsonResponse:
             fatlink_type = fatlink.link_type.name
 
         creator = fatlink.creator.username
-        if fatlink.creator.profile.main_character is not None:
-            creator = fatlink.creator.profile.main_character.character_name
+        user_has_no_profile = False
+
+        try:
+            creator_profile = fatlink.creator.profile
+        except Exception:
+            user_has_no_profile = True
+
+        if user_has_no_profile is False:
+            if creator_profile.main_character is not None:
+                creator = creator_profile.main_character.character_name
+
         time = fatlink.ifattime
         fats_number = fatlink.number_of_fats
 
@@ -837,6 +847,7 @@ def link_add(request):
         "msg": msg,
         "permissions": permissions,
         "has_open_esi_fleet": has_open_esi_fleet,
+        "default_expiry_time": IMICUSFAT_DEFAULT_FATLINK_EXPIRY_TIME,
     }
 
     logger.info("Add FAT link view called by %s", request.user)
